@@ -21,6 +21,8 @@ Copyright (c) 2007 Christopher Perkins
 Original Version by Christopher Perkins 2007Database
 Released under MIT license.
 """
+import itertools
+import sqlalchemy
 from sqlalchemy.schema import Column
 from sqlalchemy.types import *
 from sqlalchemy.orm import PropertyLoader, SynonymProperty
@@ -30,6 +32,18 @@ from tw.forms.fields import *
 
 from sprox.widgets import *
 
+try: #pragma:no cover
+    from sqlalchemy.types import LargeBinary
+except: #pragma:no cover
+    class LargeBinary:
+        pass
+
+try: #pragma:no cover
+    from sqlalchemy.types import Enum
+except: #pragma:no cover
+    class Enum:
+        pass
+
 class WidgetSelector:
     def select(self, field):
         return Widget
@@ -51,6 +65,7 @@ text_field_limit=100
 class SAWidgetSelector(WidgetSelector):
 
     default_widgets = {
+    Enum: SingleSelectField,
     String:   TextField,
     Integer:  TextField,
     Numeric:  TextField,
@@ -58,10 +73,12 @@ class SAWidgetSelector(WidgetSelector):
     Date:     SproxCalendarDatePicker,
     Time:     SproxTimePicker,
     Binary:   FileField,
+    LargeBinary: FileField,
     PickleType: TextField,
     Boolean: SproxCheckBox,
 #    NullType: TextField
     }
+    default_widgets_priority = [ Enum ]
 
     default_name_based_widgets = {}
     
@@ -93,7 +110,7 @@ class SAWidgetSelector(WidgetSelector):
             return self.default_single_select_field_widget_type
 
         type_ = String
-        for t in self.default_widgets.keys():
+        for t in itertools.chain(self.default_widgets_priority, self.default_widgets.keys()):
             if isinstance(field.type, t):
                 type_ = t
                 break
